%global with_debug 1

%if 0%{?with_debug}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package %{nil}
%endif

%if 0%{?fedora}
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%else
%if 0%{?rhel} > 7
%define gobuild(o:) go build -buildmode pie -compiler gc -tags="rpm_crashtraceback libtrust_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%else
# Golang minor version
%define gominver 16
%define gobuild(o:) scl enable go-toolset-1.%{gominver} -- go build -buildmode pie -compiler gc -tags="rpm_crashtraceback libtrust_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%endif
%endif

%global provider github
%global provider_tld com
%global project cri-o
%global repo cri-o
# https://github.com/cri-o/cri-o
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}
%global commit0 8faeccbf1cdef80635b4c75a2e2d65e8b4d4146c
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})
%global git0 https://%{import_path}

%global service_name crio

Name: %{repo}
Version: 1.21.6
Release: 7.rhaos4.8.git%{shortcommit0}%{?dist}
Summary: Kubernetes Container Runtime Interface for OCI-based containers
License: ASL 2.0
URL: %{git0}
Source0: %{git0}/archive/%{commit0}/%{name}-%{shortcommit0}.tar.gz
Source1: seccomp.json
Source3: %{service_name}-network.sysconfig
Source4: %{service_name}-storage.sysconfig
Source5: %{service_name}-metrics.sysconfig
Source6: %{service_name}.service
%if 0%{?rhel} && ! 0%{?fedora}
BuildRequires: go-toolset-1.%{gominver}
%else
BuildRequires: golang
%endif
BuildRequires: git
BuildRequires: glib2-devel
BuildRequires: glibc-static
BuildRequires: go-md2man
BuildRequires: gpgme-devel
BuildRequires: libassuan-devel
BuildRequires: libseccomp-devel
BuildRequires: make
BuildRequires: pkgconfig(systemd)
Requires(pre): container-selinux
Requires: skopeo-containers >= 1:0.1.40-1
Requires: runc >= 1.0.0-61.rc8
Obsoletes: ocid <= 0.3
Provides: ocid = %{version}-%{release}
Provides: %{service_name} = %{version}-%{release}
Requires: containernetworking-plugins >= 0.8.2-3
Requires: conmon >= 2.0.2-2

%description
%{summary}

%prep
%autosetup -Sgit -n %{name}-%{commit0}
cp %{SOURCE6} contrib/systemd/.
sed -i 's/\.gopathok //' Makefile
sed -i 's/%{version}/%{version}-%{release}/' internal/version/version.go
sed -i 's/\/local//' contrib/systemd/%{service_name}.service
sed -i 's/\/local//' contrib/systemd/%{service_name}-wipe.service

%build
mkdir _output
pushd _output
mkdir -p src/%{provider}.%{provider_tld}/{%{project},opencontainers}
ln -s $(dirs +1 -l) src/%{import_path}
popd

ln -s vendor src
export GOPATH=$(pwd)/_output:$(pwd)
export BUILDTAGS="selinux seccomp exclude_graphdriver_devicemapper exclude_graphdriver_btrfs containers_image_ostree_stub"
export GO111MODULE=off
# https://bugzilla.redhat.com/show_bug.cgi?id=1825623
export VERSION=%{version}
# build crio
%gobuild -o bin/%{service_name} %{import_path}/cmd/%{service_name}

# build crio-status
%gobuild -o bin/crio-status %{import_path}/cmd/crio-status

# build pinns and docs
%{__make} bin/pinns
%if 0%{?rhel} <= 7 && ! 0%{?fedora}
GO_MD2MAN=go-md2man GO="scl enable go-toolset-1.%{gominver} -- go" %{__make} docs
%else
GO_MD2MAN=go-md2man %{__make} docs
%endif

%install
./bin/%{service_name} \
      --selinux \
      --cgroup-manager "systemd" \
      --storage-driver "overlay" \
      --cni-plugin-dir "%{_libexecdir}/cni" \
      --storage-opt "overlay.override_kernel_check=1" \
      --metrics-port 9537 \
      --enable-metrics \
      config > %{service_name}.conf

# install conf files
install -dp %{buildroot}%{_sysconfdir}/cni/net.d
install -p -m 644 contrib/cni/10-crio-bridge.conf %{buildroot}%{_sysconfdir}/cni/net.d/100-crio-bridge.conf
install -p -m 644 contrib/cni/99-loopback.conf %{buildroot}%{_sysconfdir}/cni/net.d/200-loopback.conf

install -dp %{buildroot}%{_sysconfdir}/sysconfig
#install -p -m 644 contrib/sysconfig/%%{service_name} %%{buildroot}%%{_sysconfdir}/sysconfig/%%{service_name}
install -p -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-network
install -p -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-storage
install -p -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-metrics

make PREFIX=%{buildroot}%{_prefix} DESTDIR=%{buildroot} \
            install.bin-nobuild \
            install.completions \
            install.config-nobuild \
            install.man-nobuild \
            install.systemd

# install seccomp.json
install -p -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{service_name}/seccomp.json

install -dp %{buildroot}%{_sharedstatedir}/containers
install -dp %{buildroot}%{_sharedstatedir}/cni/bin
install -dp %{buildroot}%{_sysconfdir}/kubernetes/cni/net.d
install -dp %{buildroot}%{_datadir}/containers/oci/hooks.d
install -dp %{buildroot}/opt/cni/bin

%check
%if 0%{?with_check}
export GOPATH=%{buildroot}/%{gopath}:$(pwd)/Godeps/_workspace:%{gopath}
%endif

%post
%systemd_post %{service_name}

%preun
%systemd_preun %{service_name}

%postun
%systemd_postun_with_restart %{service_name}

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{service_name}
%{_bindir}/%{service_name}-status
%{_bindir}/pinns
%{_mandir}/man5/%{service_name}.conf*5*
%{_mandir}/man8/%{service_name}*.8*
%dir %{_sysconfdir}/%{service_name}
%config(noreplace) %{_sysconfdir}/%{service_name}/%{service_name}.conf
%config(noreplace) %{_sysconfdir}/%{service_name}/seccomp.json
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-storage
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-network
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-metrics
%config(noreplace) %{_sysconfdir}/cni/net.d/100-%{service_name}-bridge.conf
%config(noreplace) %{_sysconfdir}/cni/net.d/200-loopback.conf
%config(noreplace) %{_sysconfdir}/crictl.yaml
%{_unitdir}/%{service_name}.service
%{_unitdir}/%{name}.service
%{_unitdir}/%{service_name}-shutdown.service
%{_unitdir}/%{service_name}-wipe.service
%dir %{_sharedstatedir}/containers
%dir %{_sharedstatedir}/cni
%dir %{_sharedstatedir}/cni/bin
%dir %{_sysconfdir}/kubernetes
%dir %{_sysconfdir}/kubernetes/cni
%dir %{_sysconfdir}/kubernetes/cni/net.d
%dir %{_datadir}/containers
%dir %{_datadir}/containers/oci
%dir %{_datadir}/containers/oci/hooks.d
%dir /opt/cni
%dir /opt/cni/bin
%dir %{_datadir}/oci-umount
%dir %{_datadir}/oci-umount/oci-umount.d
%{_datadir}/oci-umount/oci-umount.d/%{service_name}-umount.conf
%{_datadir}/bash-completion/completions/%{service_name}*
%{_datadir}/fish/completions/%{service_name}*.fish
%{_datadir}/zsh/site-functions/_%{service_name}*

%changelog
* Thu May 12 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.6-7.rhaos4.8.git8faeccb
- autobuilt 8faeccb

* Thu May 12 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.6-6.rhaos4.8.git014ce61
- autobuilt 014ce61

* Wed May 11 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.6-5.rhaos4.8.git173d83e
- autobuilt 173d83e

* Tue May 10 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.6-4.rhaos4.8.git52bce89
- autobuilt 52bce89

* Thu Apr 14 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.6-3.rhaos4.8.git19780ee
- autobuilt 19780ee

* Mon Mar 21 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.6-2.rhaos4.8.gitb948fcd
- bump to 1.21.6
- autobuilt b948fcd

* Mon Mar 21 2022 Peter Hunt <pehunt@redhat.com> - 1.21.5-4.rhaos4.8.gitaf64931
- revert sysctl patch

* Thu Mar 10 2022 Peter Hunt <pehunt@redhat.com> - 1.21.5-3.rhaos4.8.gitaf64931
- add sysctl patch for CVE-2022-0811

* Sat Mar 05 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.5-2.rhaos4.8.gitaf64931
- bump to 1.21.5
- autobuilt af64931

* Tue Mar 01 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.4-12.rhaos4.8.git030755e
- autobuilt 030755e

* Mon Feb 21 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.4-11.rhaos4.8.git13048cc
- autobuilt 13048cc

* Wed Feb 02 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.4-10.rhaos4.8.gitc058478
- autobuilt c058478

* Fri Jan 21 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.4-9.rhaos4.8.gitaebb17b
- autobuilt aebb17b

* Fri Jan 21 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.4-8.rhaos4.8.git50eca9f
- autobuilt 50eca9f

* Wed Jan 05 2022 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.4-7.rhaos4.8.git91c3cb8
- autobuilt 91c3cb8

* Tue Dec 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.4-6.rhaos4.8.gitc9f28e4
- autobuilt c9f28e4

* Thu Dec 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.4-5.rhaos4.8.gitc845cf4
- autobuilt c845cf4

* Sat Nov 27 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.4-4.rhaos4.8.git84fa55d
- bump to 1.21.4
- autobuilt 84fa55d

* Fri Nov 12 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.4-3.rhaos4.8.git84fa55d
- autobuilt 84fa55d

* Tue Nov 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.4-2.rhaos4.8.git61748dc
- bump to 1.21.4
- autobuilt 61748dc

* Wed Nov 03 2021 Peter Hunt <pehunt@redhat.com> - 1.21.3-9.rhaos4.8.git7415a53
- bump version

* Fri Oct 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.3-8.rhaos4.8.git7415a53
- autobuilt 7415a53

* Thu Oct 14 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.3-7.rhaos4.8.gite87e050
- autobuilt e87e050

* Mon Oct 11 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.3-6.rhaos4.8.gite34bf50
- autobuilt e34bf50

* Thu Oct 07 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.3-5.rhaos4.8.gitb6c7cb9
- autobuilt b6c7cb9

* Fri Oct 01 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.3-4.rhaos4.8.git2933275
- autobuilt 2933275

* Fri Sep 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.3-3.rhaos4.8.git3583716
- autobuilt 3583716

* Fri Sep 10 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.3-2.rhaos4.8.gitff0b7fe
- bump to 1.21.3
- autobuilt ff0b7fe

* Mon Aug 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.2-15.rhaos4.8.gitcdc4f56
- autobuilt cdc4f56

* Thu Aug 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.2-14.rhaos4.8.gitcd588bf
- autobuilt cd588bf

* Thu Aug 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.2-13.rhaos4.8.git52b3f98
- autobuilt 52b3f98

* Tue Aug 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.2-12.rhaos4.8.git6700fde
- autobuilt 6700fde

* Mon Aug 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.2-11.rhaos4.8.git5d31399
- autobuilt 5d31399

* Wed Aug 11 2021 Peter Hunt <pehunt@redhat.com> - 1.21.2-10.rhaos4.8.git3b87110
- use conmon from path

* Tue Aug 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.2-9.rhaos4.8.git3b87110
- autobuilt 3b87110

* Fri Jul 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.2-8.rhaos4.8.git8d4264e
- autobuilt 8d4264e

* Mon Jul 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.2-7.rhaos4.8.gitdd89bfb
- autobuilt dd89bfb

* Fri Jul 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.2-6.rhaos4.8.git54a5889
- autobuilt 54a5889

* Mon Jul 19 2021 Peter Hunt <pehunt@redhat.com> - 1.21.2-5.rhaos4.8.gitb27d974
- add kubelet as a dependency in service

* Mon Jul 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.2-4.rhaos4.8.gitb27d974
- autobuilt b27d974

* Mon Jul 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.2-3.rhaos4.8.gitaaefa6b
- autobuilt aaefa6b

* Mon Jul 19 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.2-2.rhaos4.8.gite929d72
- bump to 1.21.2
- autobuilt e929d72

* Fri Jul 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.1-14.rhaos4.8.gitf97bf4d
- autobuilt f97bf4d

* Thu Jul 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.1-13.rhaos4.8.git8d20153
- autobuilt 8d20153

* Wed Jun 30 2021 Peter Hunt <pehunt@redhat.com> - 1.21.1-12.rhaos4.8.git30ca719
- rebuild for golang fips fixes

* Thu Jun 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.1-11.rhaos4.8.git30ca719
- autobuilt 30ca719

* Mon Jun 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.1-10.rhaos4.8.gitd3e59a4
- autobuilt d3e59a4

* Wed Jun 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.1-9.rhaos4.8.gitdfcd2b6
- autobuilt dfcd2b6

* Thu Jun 10 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.1-8.rhaos4.8.git7e41de0
- autobuilt 7e41de0

* Wed Jun 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.1-7.rhaos4.8.git8f26da3
- autobuilt 8f26da3

* Wed Jun 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.1-6.rhaos4.8.git0be9ef8
- autobuilt 0be9ef8

* Tue Jun 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.1-5.rhaos4.8.git4f19d38
- autobuilt 4f19d38

* Tue Jun 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.1-4.rhaos4.8.git478f49d
- autobuilt 478f49d

* Sun Jun 06 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.1-3.rhaos4.8.gite1bc46b
- autobuilt e1bc46b

* Thu Jun 03 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.1-2.rhaos4.8.gitf635341
- bump to 1.21.1
- autobuilt f635341

* Fri May 28 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-99.rhaos4.8.git3dfc2a1
- autobuilt 3dfc2a1

* Wed May 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-98.rhaos4.8.gitb7e74a3
- autobuilt b7e74a3

* Mon May 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-97.rhaos4.8.git1f3c5cb
- autobuilt 1f3c5cb

* Fri May 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-96.rhaos4.8.git1baccda
- autobuilt 1baccda

* Fri May 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-95.rhaos4.8.git3ef4247
- autobuilt 3ef4247

* Thu May 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-94.rhaos4.8.gite705872
- autobuilt e705872

* Thu May 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-93.rhaos4.8.gita83474c
- autobuilt a83474c

* Wed May 12 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-92.rhaos4.8.git8f8bcd9
- autobuilt 8f8bcd9

* Tue May 11 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-91.rhaos4.8.gitb186f24
- autobuilt b186f24

* Mon May 10 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-90.rhaos4.8.git0f38d58
- autobuilt 0f38d58

* Thu May 06 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-89.rhaos4.8.git07becf8
- autobuilt 07becf8

* Thu May 06 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-88.rhaos4.8.git3f6209a
- autobuilt 3f6209a

* Wed May 05 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-87.rhaos4.8.gitfd485de
- autobuilt fd485de

* Fri Apr 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-86.rhaos4.8.git52e15e0
- autobuilt 52e15e0

* Fri Apr 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-85.rhaos4.8.gita953b5b
- autobuilt a953b5b

* Fri Apr 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-84.rhaos4.8.gite8d733d
- autobuilt e8d733d

* Thu Apr 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-83.rhaos4.8.gitfd8043b
- autobuilt fd8043b

* Wed Apr 28 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-82.rhaos4.8.git7030929
- autobuilt 7030929

* Tue Apr 27 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-81.rhaos4.8.git451e1ad
- autobuilt 451e1ad

* Tue Apr 27 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-80.rhaos4.8.gitbc63075
- autobuilt bc63075

* Tue Apr 27 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-79.rhaos4.8.git0cf86c6
- autobuilt 0cf86c6

* Mon Apr 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-78.rhaos4.8.git9490230
- autobuilt 9490230

* Sat Apr 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-77.rhaos4.8.gitdd0b833
- autobuilt dd0b833

* Fri Apr 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-76.rhaos4.8.git2567995
- autobuilt 2567995

* Thu Apr 22 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-75.rhaos4.8.git05bced5
- autobuilt 05bced5

* Wed Apr 21 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-74.rhaos4.8.git69b1b01
- autobuilt 69b1b01

* Tue Apr 13 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-73.rhaos4.8.gitbc1ef35
- autobuilt bc1ef35

* Tue Apr 13 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-72.rhaos4.8.git2fc6693
- autobuilt 2fc6693

* Tue Apr 13 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-71.rhaos4.8.gitd2da3f5
- autobuilt d2da3f5

* Tue Apr 13 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-70.rhaos4.8.git3ca698f
- autobuilt 3ca698f

* Tue Apr 13 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-69.rhaos4.8.git0d2b3e2
- autobuilt 0d2b3e2

* Tue Apr 13 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-68.rhaos4.8.git6abbf9b
- autobuilt 6abbf9b

* Mon Apr 12 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-67.rhaos4.8.gita43e1f1
- autobuilt a43e1f1

* Mon Apr 12 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-66.rhaos4.8.gita08d776
- autobuilt a08d776

* Mon Apr 12 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-65.rhaos4.8.gitcf214df
- autobuilt cf214df

* Mon Apr 12 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-64.rhaos4.8.git6564a2b
- autobuilt 6564a2b

* Sat Apr 10 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-63.rhaos4.8.git7e36349
- autobuilt 7e36349

* Fri Apr 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-62.rhaos4.8.gitda81fd7
- autobuilt da81fd7

* Fri Apr 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-61.rhaos4.8.git8118d4a
- autobuilt 8118d4a

* Thu Apr 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-60.rhaos4.8.gitaab1c9a
- autobuilt aab1c9a

* Thu Apr 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-59.rhaos4.8.gitebfea30
- autobuilt ebfea30

* Thu Apr 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-58.rhaos4.8.gitecb1fcb
- autobuilt ecb1fcb

* Wed Apr 07 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-57.rhaos4.8.gitb012b01
- autobuilt b012b01

* Wed Apr 07 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-56.rhaos4.8.gitb77a78e
- autobuilt b77a78e

* Wed Apr 07 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-55.rhaos4.8.gitf4d2757
- autobuilt f4d2757

* Wed Apr 07 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-54.rhaos4.8.git05d2d50
- autobuilt 05d2d50

* Fri Apr 02 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-53.rhaos4.8.gitec8716f
- autobuilt ec8716f

* Thu Apr 01 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-52.rhaos4.8.gitcae4839
- autobuilt cae4839

* Thu Apr 01 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-51.rhaos4.8.gite6c19d7
- autobuilt e6c19d7

* Thu Apr 01 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-50.rhaos4.8.git43c49b2
- autobuilt 43c49b2

* Wed Mar 31 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-49.rhaos4.8.git0ec3a4f
- autobuilt 0ec3a4f

* Wed Mar 31 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-48.rhaos4.8.gita2fec8a
- autobuilt a2fec8a

* Wed Mar 31 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-47.rhaos4.8.git6c3af57
- autobuilt 6c3af57

* Tue Mar 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-46.rhaos4.8.gitd257197
- autobuilt d257197

* Tue Mar 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-45.rhaos4.8.gitc00c71e
- autobuilt c00c71e

* Tue Mar 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-44.rhaos4.8.git5fcd229
- autobuilt 5fcd229

* Tue Mar 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-43.rhaos4.8.gitfbe93a1
- autobuilt fbe93a1

* Tue Mar 30 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-42.rhaos4.8.git373a0db
- autobuilt 373a0db

* Mon Mar 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-41.rhaos4.8.gitcfb670f
- autobuilt cfb670f

* Mon Mar 29 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-40.rhaos4.8.gite661544
- autobuilt e661544

* Fri Mar 26 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-39.rhaos4.8.git3cf4a99
- autobuilt 3cf4a99

* Wed Mar 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-38.rhaos4.8.git50b6b5c
- autobuilt 50b6b5c

* Wed Mar 24 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-37.rhaos4.8.git8a0ee4d
- autobuilt 8a0ee4d

* Tue Mar 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-36.rhaos4.8.gitb6e20b4
- autobuilt b6e20b4

* Tue Mar 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-35.rhaos4.8.git2a69f9f
- autobuilt 2a69f9f

* Tue Mar 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-34.rhaos4.8.git0646a8b
- autobuilt 0646a8b

* Tue Mar 23 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-33.rhaos4.8.git72ce0e9
- autobuilt 72ce0e9

* Mon Mar 22 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-32.rhaos4.8.gitcb00edb
- autobuilt cb00edb

* Mon Mar 22 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-31.rhaos4.8.git30ec358
- autobuilt 30ec358

* Sat Mar 20 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-30.rhaos4.8.gitf2f339d
- autobuilt f2f339d

* Thu Mar 18 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-29.rhaos4.8.git4fff699
- autobuilt 4fff699

* Wed Mar 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-28.rhaos4.8.git31983bf
- autobuilt 31983bf

* Wed Mar 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-27.rhaos4.8.git2115af9
- autobuilt 2115af9

* Wed Mar 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-26.rhaos4.8.git7e01cb1
- autobuilt 7e01cb1

* Tue Mar 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-25.rhaos4.8.git62aecc3
- autobuilt 62aecc3

* Tue Mar 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-24.rhaos4.8.git69cc531
- autobuilt 69cc531

* Tue Mar 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-23.rhaos4.8.git1e86661
- autobuilt 1e86661

* Mon Mar 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-22.rhaos4.8.gitcfb8120
- autobuilt cfb8120

* Fri Mar 12 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-21.rhaos4.8.git076a619
- autobuilt 076a619

* Thu Mar 11 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-20.rhaos4.8.gite9bf587
- autobuilt e9bf587

* Wed Mar 10 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-19.rhaos4.8.gitd6cc960
- autobuilt d6cc960

* Wed Mar 10 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-18.rhaos4.8.git1c5111b
- autobuilt 1c5111b

* Wed Mar 10 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-17.rhaos4.8.git935532b
- autobuilt 935532b

* Tue Mar 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-16.rhaos4.8.gitbd99d77
- autobuilt bd99d77

* Tue Mar 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-15.rhaos4.8.git1105977
- autobuilt 1105977

* Tue Mar 09 2021 Peter Hunt <pehunt@redhat.com> - 1.21.0-14.rhaos4.8.git584f175
- revert to 584f175f148a12cbeb08224f65ff37c9fafe76fe

* Mon Mar 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-13.rhaos4.8.git8446438
- autobuilt 8446438

* Mon Mar 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-12.rhaos4.8.gitda128d6
- autobuilt da128d6

* Wed Feb 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-11.rhaos4.8.git7373da2
- autobuilt 7373da2

* Wed Feb 17 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-10.rhaos4.8.gitd522b73
- autobuilt d522b73

* Tue Feb 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-9.rhaos4.8.git900bc42
- autobuilt 900bc42

* Tue Feb 16 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-8.rhaos4.8.git4f9a59b
- autobuilt 4f9a59b

* Mon Feb 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-7.rhaos4.8.git7ca35f0
- autobuilt 7ca35f0

* Mon Feb 15 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-6.rhaos4.8.gitf691e06
- autobuilt f691e06

* Fri Feb 12 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-5.rhaos4.8.git46263d7
- autobuilt 46263d7

* Fri Feb 12 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-4.rhaos4.8.gitc787156
- autobuilt c787156

* Fri Feb 12 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-3.rhaos4.8.git49b2453
- autobuilt 49b2453

* Thu Feb 11 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.21.0-2.rhaos4.8.gitf9f73da
- bump to 1.21.0
- autobuilt f9f73da

* Tue Feb 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-5.rhaos4.8.git7f6ccb5
- autobuilt 7f6ccb5

* Tue Feb 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-4.rhaos4.8.gitbae5d1f
- autobuilt bae5d1f

* Tue Feb 09 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-3.rhaos4.8.gitfd2a16d
- autobuilt fd2a16d

* Mon Feb 08 2021 Peter Hunt (Bot) <pehunt+bot@redhat.com> - 1.20.0-2.rhaos4.8.gitc33ecfe
- bump to 1.20.0
- autobuilt c33ecfe

* Fri Feb 05 2021 Peter Hunt <pehunt@redhat.com> - 1.21.0-0.rhaos4.8.gitf39e3d0.1
- Initial 4.8 build
